==> org-lsst-ccs-subsystem-fcs-gui-1.4.6-sources.jar: org/lsst/ccs/subsystems/fcs/singlefiltertest/ui/SingleFilterTestGUISubsystem.java <==
package org.lsst.ccs.subsystems.fcs.singlefiltertest.ui;

import javax.swing.JScrollPane;
import org.lsst.ccs.Subsystem;
import org.lsst.ccs.bus.CommandReply;
import org.lsst.ccs.bus.ModuleInvokerCommand;
import org.lsst.ccs.subsystems.fcs.singlefiltertest.config.SingleFilterTestConfig;

import javax.swing.*;
import java.io.PrintWriter;
import org.lsst.ccs.bus.DataStatusListener;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByBasicAutoChanger;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByCarousel;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByClamp;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByClampActuator;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByLatch;

/**
 *
 * @author max
 */
public class SingleFilterTestGUISubsystem extends Subsystem implements DataStatusListener {

    private static final String destination = "single-filter-test";
    //private static final Logger log = Logger.getLogger("org.lsst.ccs.subsystems.fcs");
    private PrintWriter out = new PrintWriter(System.out, true);
//    private SingleFilterTestAssembly assembly;
    private final FilterExchangeMainPanel assembly;
//    private CarouselTablePanel carouselTable;
    private long lastHeartBeat = 0, lastStateRequest = 0;
    private boolean initialized = false;
    String stateCorrelId;
    JScrollPane pane;

    public SingleFilterTestGUISubsystem() {
//        assembly = new SingleFilterTestAssembly(this);
        assembly = new FilterExchangeMainPanel(this);
//        carouselTable = assembly.getCarouselTable();
//        panel = assembly.getControlPanel();
        pane = new JScrollPane(assembly);
//        pane.setPreferredSize(assembly.getPreferredSize());
    }

    public void initGui() {
        setName("SingleFilterTestGUIModule");        
        setListenToStatus(true);
        setStatusBroadcastPeriod(0);
        start();
    }

    public JComponent getGuiLayout() {
        return pane;
    }

    public void resetGui() {
    }

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {

        System.setProperty("java.naming.factory.initial",
                "com.sun.enterprise.naming.SerialInitContextFactory");
        System.setProperty("java.naming.factory.url.pkgs",
                "com.sun.enterprise.naming");
        System.setProperty("java.naming.factory.state",
                "com.sun.corba.ee.impl.presentation.rmi.JNDIStateFactoryImpl");
        System.setProperty("org.omg.CORBA.ORBInitialHost",
                args.length >= 1 ? args[0] : "localhost");
        System.setProperty("org.omg.CORBA.ORBInitialPort", "3700");

//        Properties props = FrameworkUtils.loadProperties(FrameworkUtils.getDefaultJndiProperties(),RefrigGUISubsystem.class.getClass(),"jndi.properties");

        SingleFilterTestGUISubsystem t = new SingleFilterTestGUISubsystem();

        JFrame frame = new JFrame("Single Filter Test Subsystem");
        frame.setContentPane(t.getGuiLayout());
        frame.pack();
        frame.setVisible(true);
        t.initGui();
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    }

    public void setPrintWriter(PrintWriter out) {
        this.out = out;
    }

    @Override
    public void onReply(CommandReply s) {
        //FIXME temporary fix to prevent multiple GUIs from interfering with each other.
        //See https://jira.slac.stanford.edu/browse/LSSTCCS-9
        if (s.getCorrelId().equals(stateCorrelId)) {
            
            SingleFilterTestConfig config = (SingleFilterTestConfig) s.getReply();
            assembly.initializeGui(config);
//            carouselTable.createTableRows(config);
//            panel.updateControlPanel(r.getRefrigState());
            initialized = true;
        }
    }



    @Override
    public void onDataArrival(String source, long timestamp, String dataType, Object s) {
         //If this data status is not for us we forget it.
        if (!source.equals(destination)) return;
        if (initialized) {
            switch (dataType){
                            case "carouselClamp":
                                log.debug(getName() + " read data dataType:carouselClamp");
                                assembly.updateClamp((StatusDataPublishedByClamp) s);
                                lastHeartBeat = timestamp;
                                break;
                                
                            case "actuator":
                                log.debug(getName() + " read data dataType:actuator");
                                assembly.updateActuator((StatusDataPublishedByClampActuator) s);
                                lastHeartBeat = timestamp;
                                break;
                                
                            case "carousel":
                                log.debug(getName() + " read data dataType:carousel");
                                assembly.updateCarousel((StatusDataPublishedByCarousel) s);
                                lastHeartBeat = timestamp;
                                break;
                                
                            case "autochangerLatch":
                                log.debug(getName() + " read data dataType:autochangerLatch");
                                assembly.updateLatch((StatusDataPublishedByLatch) s);
                                lastHeartBeat = timestamp;
                                break;
                                
                            case "autochanger":
                                log.debug(getName() + " read data dataType:autochanger");
                                assembly.updateAutoChanger ((StatusDataPublishedByBasicAutoChanger) s);
                                lastHeartBeat = timestamp;
                                break;                                
                                                             
                            default:
                                log.warning(getName() + " An unexpected dataType was read on the status bus:" + dataType);
                                break;
                            
                        }
        } else {
            long currentTime = System.currentTimeMillis();
            if (currentTime - lastStateRequest > 2000) {
                lastStateRequest = currentTime;
                ModuleInvokerCommand cmd = new ModuleInvokerCommand("getFullState");
                sendCommand(cmd);
                stateCorrelId = cmd.getCorrelId();
            }
        }
    }

    private void sendCommand(ModuleInvokerCommand cmd) {
        cmd.setDestination(destination);
        updateCurrentSubsystem();
        fac.sendCommand(cmd);
    }
    
    //    //this method is no more used since this implements DataStatusListener
//    @Override
//    public void onStatus(BusMessage s) {
//
//        if (initialized) {
////            if (s instanceof StatusDataPublishedByClamp) {
////                assembly.updateClamp((StatusDataPublishedByClamp) s);
////                lastHeartBeat = s.getTimeStamp();
////            
////            } else if ( s instanceof StatusDataPublishedByBasicAutoChanger ) {
////                assembly.updateAutoChanger((StatusDataPublishedByBasicAutoChanger)s);
////                lastHeartBeat = s.getTimeStamp();
////            } else if ( s instanceof StatusDataPublishedByLatch ) {
////                assembly.updateLatch((StatusDataPublishedByLatch)s);
////                lastHeartBeat = s.getTimeStamp();
////            } else if ( s instanceof StatusDataPublishedByCarousel ) {
////                assembly.updateCarousel((StatusDataPublishedByCarousel)s);
////                lastHeartBeat = s.getTimeStamp();
////            } else if ( s instanceof StatusDataPublishedByClampActuator ) {
////                assembly.updateActuator((StatusDataPublishedByClampActuator)s);
////                lastHeartBeat = s.getTimeStamp();                
////            } else 
//                
//            if ( s instanceof EncodedDataStatus) {
//                log.debug(getName() + " read an EncodedDataStatus");
//                EncodedDataStatus dataStatus = (EncodedDataStatus)s;
//                log.debug("dataStatus/origin:" + dataStatus.getOrigin());
//                
//                //If this data status is not for us we forget it.
//                if (!dataStatus.getOrigin().equals(destination)) return;
//                
//                KVList kvlist = dataStatus.getContent();
//                //KeyData is the internal representation of key-encoded value
//                KeyData kd = kvlist.getPair("dataType");
//                Optional<Object> opt = kd.getValue() ;
//                    if(opt.isPresent()) {
//                        
//                        String dataType = String.valueOf(opt.get());
//                        
//                        switch (dataType){
//                            case "carouselClamp":
//                                log.debug(getName() + " Received a kvlist dataType:carouselClamp");
//                                assembly.updateClamp(kvlist);
//                                lastHeartBeat = s.getTimeStamp();
//                                break;
//                                
//                            case "actuator":
//                                log.debug(getName() + " Received a kvlist dataType:actuator");
//                                //assembly.updateActuator(kvlist);
//                                assembly.updateActuator(FcsGuiUtils.getMapFromKVList(kvlist));
//                                lastHeartBeat = s.getTimeStamp();
//                                break;
//                                
//                            case "carousel":
//                                log.debug(getName() + " Received a kvlist dataType:carousel");
//                                assembly.updateCarousel(kvlist);
//                                lastHeartBeat = s.getTimeStamp();
//                                break;
//                                
//                            case "autochangerLatch":
//                                log.debug(getName() + " Received a kvlist dataType:autochangerLatch");
//                                assembly.updateLatch(kvlist);
//                                lastHeartBeat = s.getTimeStamp();
//                                break;
//                                
//                            case "autochanger":
//                                log.debug(getName() + " Received a kvlist dataType:autochanger");
//                                assembly.updateAutoChanger(FcsGuiUtils.getMapFromKVList(kvlist));
//                                lastHeartBeat = s.getTimeStamp();
//                                break;
//                                
//                            default:
//                                log.warning(getName() + " An unexpected dataType was read on the status bus:" + dataType);
//                                break;
//                            
//                        }
//                       
//                    } else {
//                        log.error(getName() + " : no dataType found in EncodedDataStatus" + dataStatus.toString());
//                    }
//                    
//            } else System.out.println("****** "+s.getClass());
//            
//        } else { // if not initialized yet
//            long currentTime = System.currentTimeMillis();
//            if (currentTime - lastStateRequest > 2000) {
//                lastStateRequest = currentTime;
//                ModuleInvokerCommand cmd = new ModuleInvokerCommand("getFullState");
//                sendCommand(cmd);
//                stateCorrelId = cmd.getCorrelId();
//            }
//        }
//    }
    
}

==> org-lsst-ccs-subsystem-fcs-gui-2.0.1-sources.jar: org/lsst/ccs/subsystems/fcs/singlefiltertest/ui/SingleFilterTestGUISubsystem.java <==
package org.lsst.ccs.subsystems.fcs.singlefiltertest.ui;

import javax.swing.JScrollPane;
import org.lsst.ccs.Subsystem;
import org.lsst.ccs.bus.CommandReply;
import org.lsst.ccs.bus.ModuleInvokerCommand;
import org.lsst.ccs.subsystems.fcs.singlefiltertest.config.SingleFilterTestConfig;

import javax.swing.*;
import java.io.PrintWriter;
import org.lsst.ccs.bus.DataStatusListener;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByBasicAutoChanger;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByCarousel;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByClamp;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByClampActuator;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByAutochangerLatch;

/**
 *
 * @author max
 */
public class SingleFilterTestGUISubsystem extends Subsystem implements DataStatusListener {

    private static final String destination = "single-filter-test";
    //private static final Logger log = Logger.getLogger("org.lsst.ccs.subsystems.fcs");
    private PrintWriter out = new PrintWriter(System.out, true);
//    private SingleFilterTestAssembly assembly;
    private final FilterExchangeMainPanel assembly;
//    private CarouselTablePanel carouselTable;
    private long lastHeartBeat = 0, lastStateRequest = 0;
    private boolean initialized = false;
    String stateCorrelId;
    JScrollPane pane;

    public SingleFilterTestGUISubsystem() {
        assembly = new FilterExchangeMainPanel(this);
        pane = new JScrollPane(assembly);
    }

    public void initGui() {
        setName("SingleFilterTestGUIModule");        
        setListenToStatus(true);
        setStatusBroadcastPeriod(0);
        start();
    }

    public JComponent getGuiLayout() {
        return pane;
    }

    public void resetGui() {
    }

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {

        SingleFilterTestGUISubsystem t = new SingleFilterTestGUISubsystem();

        JFrame frame = new JFrame("Single Filter Test Subsystem");
        frame.setContentPane(t.getGuiLayout());
        frame.pack();
        frame.setVisible(true);
        t.initGui();
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    }

    public void setPrintWriter(PrintWriter out) {
        this.out = out;
    }

    @Override
    public void onReply(CommandReply s) {
        //FIXME temporary fix to prevent multiple GUIs from interfering with each other.
        //See https://jira.slac.stanford.edu/browse/LSSTCCS-9
        if (s.getCorrelId().equals(stateCorrelId)) {
            
            SingleFilterTestConfig config = (SingleFilterTestConfig) s.getReply();
            assembly.initializeGui(config);
            initialized = true;
        }
    }



    @Override
    public void onDataArrival(String source, long timestamp, String dataType, Object s) {
         //If this data status is not for us we forget it.
        if (!source.equals(destination)) return;
        if (initialized) {
            switch (dataType){
                            case "carouselClamp":
                                log.debug(getName() + " read data dataType:carouselClamp");
                                assembly.updateClamp((StatusDataPublishedByClamp) s);
                                lastHeartBeat = timestamp;
                                break;
                                
                            case "actuator":
                                log.debug(getName() + " read data dataType:actuator");
                                assembly.updateActuator((StatusDataPublishedByClampActuator) s);
                                lastHeartBeat = timestamp;
                                break;
                                
                            case "carousel":
                                log.debug(getName() + " read data dataType:carousel");
                                assembly.updateCarousel((StatusDataPublishedByCarousel) s);
                                lastHeartBeat = timestamp;
                                break;
                                
                            case "autochangerLatch":
                                log.debug(getName() + " read data dataType:autochangerLatch");
                                assembly.updateLatch((StatusDataPublishedByAutochangerLatch) s);
                                lastHeartBeat = timestamp;
                                break;
                                
                            case "autochanger":
                                log.debug(getName() + " read data dataType:autochanger");
                                assembly.updateAutoChanger ((StatusDataPublishedByBasicAutoChanger) s);
                                lastHeartBeat = timestamp;
                                break;                                
                                                             
                            default:
                                log.warning(getName() + " An unexpected dataType was read on the status bus:" + dataType);
                                break;
                            
                        }
        } else {
            long currentTime = System.currentTimeMillis();
            if (currentTime - lastStateRequest > 2000) {
                lastStateRequest = currentTime;
                ModuleInvokerCommand cmd = new ModuleInvokerCommand("getFullState");
                sendCommand(cmd);
                stateCorrelId = cmd.getCorrelId();
            }
        }
    }

    private void sendCommand(ModuleInvokerCommand cmd) {
        cmd.setDestination(destination);
        updateCurrentSubsystem();
        fac.sendCommand(cmd);
    }

    
}
